@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2015 Hive Solutions Lda.
+# Copyright (c) 2008-2016 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2015 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -56,6 +56,10 @@ USAGE_MESSAGE = "encoding path [-r]\
 """ The usage message, to be printed when help is required
 or when a command line error exists """
 
+BOM_SEQUENCE = b"\xef\xbb\xbf"
+""" The byte based sequence that defines the start of
+an utf-8 bom encoded text file """
+
 def has_encoding(string_buffer, encoding):
     """
     Determines if the provided buffer is encoded in the provided encoding.
@@ -105,7 +109,13 @@ def apply_replacements_list(string_buffer, replacements_list):
     # returns the replaced string buffer
     return string_buffer
 
-def convert_encoding(file_path, source_encoding, target_encoding, windows_newline = True, replacements_list = None):
+def convert_encoding(
+    file_path,
+    source_encoding,
+    target_encoding,
+    windows_newline = True,
+    replacements_list = None
+):
     """
     Converts the encoding of the specified file.
 
@@ -131,8 +141,15 @@ def convert_encoding(file_path, source_encoding, target_encoding, windows_newlin
         # checks if the file already has the target encoding
         string_value = file.read()
         string_value = string_value.replace(b"\r\n", b"\n")
+        string_value = string_value.replace(b"\r", b"\n")
         has_target_encoding = has_encoding(string_value, target_encoding)
 
+        # in case the retrieved string value starts with the bom
+        # (byte order mark) sequence it's removed as it's considered
+        # deprecated as a method of detecting utf encoding
+        if string_value.startswith(BOM_SEQUENCE):
+            string_value = string_value[len(BOM_SEQUENCE):]
+
         # decodes the string value from the specified source encoding, this
         # operation may fail as the source encoding may only be a guess on
         # the true encoding of the file, the encodes the string value again
@@ -197,7 +214,7 @@ def convert_encoding_walker(arguments, directory_name, names):
 
     # filters the names with non valid file extensions
     valid_complete_names = [os.path.normpath(name) for name in valid_complete_names\
-        if file_extensions == None or name.split(".")[-1] in file_extensions]
+        if file_extensions == None or os.path.split(name)[-1].split(".")[-1] in file_extensions]
 
     # iterates over all the valid complete names with extension filter
     # to convert the respective file into the target encoding
@@ -207,9 +224,9 @@ def convert_encoding_walker(arguments, directory_name, names):
         extra.echo(
             "Convert encoding in file: %s (%s to %s)" %\
             (
-                 valid_complete_name,
-                 source_encoding,
-                 target_encoding
+                valid_complete_name,
+                source_encoding,
+                target_encoding
             )
         )
 
@@ -228,9 +245,9 @@ def convert_encoding_walker(arguments, directory_name, names):
             extra.warn(
                 "Failed converting encoding in file: %s (%s to %s)" %\
                 (
-                     valid_complete_name,
-                     source_encoding,
-                     target_encoding
+                    valid_complete_name,
+                    source_encoding,
+                    target_encoding
                 )
             )
 
