@@ -298,9 +298,31 @@ def process_property_lines(
     processed_property_lines = [process_property_line(property_line, line_number, indentation)\
         for property_line in property_lines if not avoid_empty or property_line.strip()]
 
+    # runs an extra step to check for any duplicated line
+    # in the set of processed property lines
+    check_duplicates(processed_property_lines, line_number)
+
     # returns the processed property lines
     return processed_property_lines
 
+def check_duplicates(property_lines, line_number):
+    # retrieves the complete set of names for the rules, this is
+    # going to be used as the base unit for duplicate checking
+    names = [line.strip().split(":", 1)[0] for line in property_lines]
+
+    # starts the sequence/list that is going to store the already
+    # visited sequence of names (for duplicate detection)
+    visited = []
+
+    # iterates over the complete set of names to detect any duplicated
+    # value printing a warning message for such situation
+    for name in names:
+        if name in visited: extra.warn(
+            "Duplicated property line '%s' at line %s" %\
+            (name, line_number)
+        )
+        visited.append(name)
+
 def process_property_line(property_line, line_number, indentation):
     # in case the property line is empty, when stripped the property
     # is considered to be empty (warning required) logs the message
@@ -551,10 +573,11 @@ def cleanup_properties(
             line_number
         )
 
-        # in case the line contains a single line comment
+        # in case the line contains a single line comment,
+        # does nothing, will write the line as is
         if "/*" in line and "*/" in line and not "*/*/" in line:
-            # does nothing, will write the line as is
             pass
+
         # in case the line contains the end of multiline comment
         elif "*/" in line:
             # in case the comment mode is currently not enabled prints
@@ -573,6 +596,7 @@ def cleanup_properties(
             # enables the needs newline flag
             comments_started = 0
             needs_newline = True
+
         # in case the line contains a the start of multiline comment
         elif "/*" in line:
             # in case the comment mode is already enabled (at least one)
@@ -589,14 +613,17 @@ def cleanup_properties(
 
             # increments the comments started counter
             comments_started += 1
-        # in case this is a comment line
+
+        # in case this is a comment line (comment started)
+        # does nothing, will just write the line as is
         elif comments_started:
-            # does nothing, will just write the line as is
             pass
+
         # in case the line contains an at rule specification
         elif AT_RULES_REGEX.match(line):
             # after an at rule, a newline must follow
             needs_newline = True
+
         # in case the line contains a full rule specification
         # does nothing, will just write line as is as there's
         # very few thing possible to optimize under this situation
@@ -604,6 +631,7 @@ def cleanup_properties(
             line = line.strip()
             needs_newline = True
             rule_started = False
+
         # in case this is a rule start line
         elif "{" in line:
             # increments the open rule count
@@ -690,19 +718,21 @@ def cleanup_properties(
             # skips further processing
             continue
 
+        # in case this is part of rule selector declaration
+        # the typical rule replacement operations are applied
+        elif line.rstrip().endswith(","):
+            line = TOKEN_REGEX.sub(r" \1 ", line)
+            line = SPACE_REGEX.sub(" ", line)
+            line = COMMA_REGEX.sub(r"\1", line)
+            line = line.strip()
+
         # in case this line is part of a valid rule set
         elif rule_started:
             # appends the line to the rule set, and then
             # skips outputting the line to the buffer
             rule_lines.append(line)
             continue
-        # in case this is part of rule selector declaration
-        # the typical rule replacement operations are applied
-        elif "," in line:
-            line = TOKEN_REGEX.sub(r" \1 ", line)
-            line = SPACE_REGEX.sub(" ", line)
-            line = COMMA_REGEX.sub(r"\1", line)
-            line = line.strip()
+
         # in case the between rules mode is active
         elif not rule_started and not line.strip():
             # increments the newlines count
@@ -716,6 +746,7 @@ def cleanup_properties(
 
             # disables the needs newline flag
             needs_newline = False
+
         else:
             # warns about the statement outside a valid rule
             extra.warn("Found statement outside rule at line %d" % line_number)
@@ -848,7 +879,7 @@ def cleanup_stylesheets_walker(arguments, directory_name, names):
     # filters the names with non valid file extensions so that
     valid_complete_names = [
         os.path.normpath(name) for name in valid_complete_names\
-        if file_extensions == None or name.split(".")[-1] in file_extensions
+        if file_extensions == None or os.path.split(name)[-1].split(".")[-1] in file_extensions
     ]
 
     # iterates over all the valid complete names with extension filter
